pub enum EditKind {
Edit,
Write,
MultiEdit,
NotebookEdit,
}Expand description
The write tool behind one file edit, normalized across the variants a tool exposes - the evidence of what kind of change a session made to a file.
Variants
Implementations