read_to_string_capped

Function read_to_string_capped 

pub fn read_to_string_capped(path: &Path) -> Result<String>
Read a file to a string, refusing anything over MAX_SESSION_FILE_BYTES so a malicious or corrupt session file can’t OOM the process.